@@ -7,11 +7,12 @@
 #' @param tokenizer A tokenizer that specifies how to break the \code{file}
 #'   up into fields, e.g., \code{\link{tokenizer_csv}},
 #'   \code{\link{tokenizer_fwf}}
+#' @param n_max Optionally, maximum number of rows to count fields for.
 #' @export
 #' @examples
 #' count_fields(system.file("extdata/mtcars.csv", package = "readr"),
 #'  tokenizer_csv())
-count_fields <- function(file, tokenizer, skip = 0) {
+count_fields <- function(file, tokenizer, skip = 0, n_max = -1L) {
   ds <- datasource(file, skip = skip)
-  count_fields_(ds, tokenizer)
+  count_fields_(ds, tokenizer, n_max)
 }
