@@ -16,6 +16,7 @@ public:
   TokenizerLine(): moreTokens_(false) {}
 
   void tokenize(SourceIterator begin, SourceIterator end) {
+    begin_ = begin;
     cur_ = begin;
     end_ = end;
     line_ = 0;
@@ -29,20 +30,25 @@ public:
 
   Token nextToken() {
     SourceIterator token_begin = cur_;
-    int line = line_;
+
+    bool hasNull = false;
 
     if (!moreTokens_)
-      return Token(TOKEN_EOF, line, 0);
+      return Token(TOKEN_EOF, line_, 0);
 
     while (cur_ != end_) {
       Advance advance(&cur_);
-      if ((line_ + 1) % 100000 == 0)
+
+      if (*cur_ == '\0')
+        hasNull = true;
+
+      if ((line_ + 1) % 500000 == 0)
         Rcpp::checkUserInterrupt();
 
       switch(*cur_) {
       case '\r':
       case '\n':
-        return Token(token_begin, advanceForLF(&cur_, end_), line, 0);
+        return Token(token_begin, advanceForLF(&cur_, end_), hasNull, line_++, 0);
       default:
         break;
       }
@@ -51,9 +57,9 @@ public:
     // Reached end of Source: cur_ == end_
     moreTokens_ = false;
     if (token_begin == end_) {
-      return Token(TOKEN_EOF, line, 0);
+      return Token(TOKEN_EOF, line_++, 0);
     } else {
-      return Token(token_begin, end_, line, 0);
+      return Token(token_begin, end_, hasNull, line_++, 0);
     }
   }
 
